# limex-bundles

`limex-bundles` is a Python library designed to make it easy to add LimEx data bundles to Zipline. This package simplifies the process of copying necessary bundle files to the correct locations within your Zipline installation.

## Features

- Automatically checks if Zipline is installed
- Copies necessary bundle files to the correct locations
- Updates the LimEx configuration with your API key

## Installation

You can install `limex-bundles` from PyPi using pip:

```sh
pip install limex-bundles